@@ -18,10 +18,10 @@ SLURM_STATE_COMPLATED = "COMPLATED"
 SLURM_STATE_RUNNING = "RUNNING"
 # redis key
 # 算子间的关系
-REDIS_KEY_FOR_ACTOR_RELATION = 'flow_mananger_for_actor_relation'
+REDIS_KEY_FOR_ACTOR_RELATION = 'flow_manager_for_actor_relation'
 # 算子的状态
-REDIS_KEY_FOR_ACTOR_STATE = 'flow_mananger_for_actor_state'
+REDIS_KEY_FOR_ACTOR_STATE = 'flow_manager_for_actor_state'
 # 算子的整体状态
-REDIS_KEY_FOR_ACTOR_FINAL_STATE = 'flow_mananger_for_actor_final_state'
+REDIS_KEY_FOR_ACTOR_FINAL_STATE = 'flow_manager_for_actor_final_state'
 # # jobId和算子间的关系
 # REDIS_KEY_FOR_JOB_MAPPING = 'flow_mananger_for_job_mapping'
\ No newline at end of file
