@@ -32,16 +32,52 @@ class Parameter(object):
         pass
 
 
-class FileParameter(Parameter):
+class FileInputParameter(Parameter):
 
     def __init__(self, name: str = None, title: str = None, description: str = "", value: str = None):
         super().__init__(name, title, description, value)
 
     def set_value(self, value: str):
-        super(FileParameter, self).set_value(value)
+        super(FileInputParameter, self).set_value(value)
 
     def value(self) -> str:
-        return str(super(FileParameter, self).get_value())
+        return str(super(FileInputParameter, self).get_value())
+
+
+class FileOutputParameter(Parameter):
+
+    def __init__(self, name: str = None, title: str = None, description: str = "", value: str = None):
+        super().__init__(name, title, description, value)
+
+    def set_value(self, value: str):
+        super(FileOutputParameter, self).set_value(value)
+
+    def value(self) -> str:
+        return str(super(FileOutputParameter, self).get_value())
+
+
+class OuterFileInputParameter(Parameter):
+
+    def __init__(self, name: str = None, title: str = None, description: str = "", value: str = None):
+        super().__init__(name, title, description, value)
+
+    def set_value(self, value: str):
+        super(OuterFileInputParameter, self).set_value(value)
+
+    def value(self) -> str:
+        return str(super(OuterFileInputParameter, self).get_value())
+
+
+class OuterFileOutputParameter(Parameter):
+
+    def __init__(self, name: str = None, title: str = None, description: str = "", value: str = None):
+        super().__init__(name, title, description, value)
+
+    def set_value(self, value: str):
+        super(OuterFileOutputParameter, self).set_value(value)
+
+    def value(self) -> str:
+        return str(super(OuterFileOutputParameter, self).get_value())
 
 
 class StringParameter(Parameter):
@@ -70,8 +106,8 @@ class IntParameter(Parameter):
 
 class ListParameter(Parameter):
 
-    def __init__(self, name: str = None, description: str = "", value: list = None):
-        super().__init__(name, description, value)
+    def __init__(self, name: str = None, title: str = None, description: str = "", value: list = None):
+        super().__init__(name, title, description, value)
 
     def set_value(self, value: list):
         super(ListParameter, self).set_value(value)
